PALM-meteo: palmmeteo_stdplugins.wrf_utils Namespace Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Functions | Variables
palmmeteo_stdplugins.wrf_utils Namespace Reference

## Classes
class | BilinearRegridder
class | CAMxCoordTransform
class | WRFCoordTransform
class | WrfPhysics

## Functions
| calc_ph_hybrid (f, it, mu)
| calc_ph_sigma (f, it, mu)
| wrf_t (f, it)
| calc_gp (f, it, ph)
| palm_wrf_gw (f, lon, lat, levels, tidx=0)
| minterp (interp_heights, data_heights, u, v)
| get_wrf_dims (f, lat, lon, xlat, xlong)
| calcgw_wrf (f, lat, lon, levels, tidx=0)
| calcgw_gfs (v, lat, lon)
| combinegw_gfs (grbs, levels, lat, lon)

## Variables
int | gw_gfs_margin_deg = 5.
| Settings for geostrophic wind.
int | gw_wrf_margin_km = 10.
| smoothing area in km gw_alpha = .143 ##< GW vertical interpolation by power law
int | gw_alpha = 1.
| ignore wind power law, interpolate linearly
| parser = argparse.ArgumentParser(description=__doc__)
| help
| args = parser.parse_args()
| f = netCDF4.Dataset(args.wrfout)
| t = WRFCoordTransform(f)
| mu = f.variables['MUB'][0,:,:] + f.variables['MU'][0,:,:]
| gp = f.variables['PH'][0,:,:,:] + f.variables['PHB'][0,:,:,:]
| phf
| phh
| gp_calc = calc_gp(f, 0, phf)
| delta = gp_calc - gp

## Detailed Description

    WRF (+CAMx) utility module for PALM dynamic driver generator

## Function Documentation

## ◆ calc_gp()

palmmeteo_stdplugins.wrf_utils.calc_gp | ( |  | f,
|  |  | it,
|  |  | ph
| ) |  |

## ◆ calc_ph_hybrid()

palmmeteo_stdplugins.wrf_utils.calc_ph_hybrid | ( |  | f,
|  |  | it,
|  |  | mu
| ) |  |

## ◆ calc_ph_sigma()

palmmeteo_stdplugins.wrf_utils.calc_ph_sigma | ( |  | f,
|  |  | it,
|  |  | mu
| ) |  |

## ◆ calcgw_gfs()

palmmeteo_stdplugins.wrf_utils.calcgw_gfs | ( |  | v,
|  |  | lat,
|  |  | lon
| ) |  |

## ◆ calcgw_wrf()

palmmeteo_stdplugins.wrf_utils.calcgw_wrf | ( |  | f,
|  |  | lat,
|  |  | lon,
|  |  | levels,
|  |  | tidx = `0`
| ) |  |

## ◆ combinegw_gfs()

palmmeteo_stdplugins.wrf_utils.combinegw_gfs | ( |  | grbs,
|  |  | levels,
|  |  | lat,
|  |  | lon
| ) |  |

## ◆ get_wrf_dims()

palmmeteo_stdplugins.wrf_utils.get_wrf_dims | ( |  | f,
|  |  | lat,
|  |  | lon,
|  |  | xlat,
|  |  | xlong
| ) |  |

    A crude method, yet satisfactory for approximate WRF surroundings

## ◆ minterp()

palmmeteo_stdplugins.wrf_utils.minterp | ( |  | interp_heights,
|  |  | data_heights,
|  |  | u,
|  |  | v
| ) |  |

    Interpolate wind using power law for agl levels

## ◆ palm_wrf_gw()

palmmeteo_stdplugins.wrf_utils.palm_wrf_gw | ( |  | f,
|  |  | lon,
|  |  | lat,
|  |  | levels,
|  |  | tidx = `0`
| ) |  |

    Calculate geostrophic wind from WRF using metpy

## ◆ wrf_t()

palmmeteo_stdplugins.wrf_utils.wrf_t | ( |  | f,
|  |  | it
| ) |  |

## Variable Documentation

## ◆ args

palmmeteo_stdplugins.wrf_utils.args = parser.parse_args()

## ◆ delta

palmmeteo_stdplugins.wrf_utils.delta = gp_calc - gp

## ◆ f

palmmeteo_stdplugins.wrf_utils.f = netCDF4.Dataset(args.wrfout)

## ◆ gp

palmmeteo_stdplugins.wrf_utils.gp = f.variables['PH'][0,:,:,:] + f.variables['PHB'][0,:,:,:]

## ◆ gp_calc

palmmeteo_stdplugins.wrf_utils.gp_calc = calc_gp(f, 0, phf)

## ◆ gw_alpha

int palmmeteo_stdplugins.wrf_utils.gw_alpha = 1.

ignore wind power law, interpolate linearly

## ◆ gw_gfs_margin_deg

int palmmeteo_stdplugins.wrf_utils.gw_gfs_margin_deg = 5.

Settings for geostrophic wind.

smoothing area in degrees lat/lon

## ◆ gw_wrf_margin_km

int palmmeteo_stdplugins.wrf_utils.gw_wrf_margin_km = 10.

smoothing area in km gw_alpha = .143 ##< GW vertical interpolation by power law

## ◆ help

palmmeteo_stdplugins.wrf_utils.help

## ◆ mu

palmmeteo_stdplugins.wrf_utils.mu = f.variables['MUB'][0,:,:] + f.variables['MU'][0,:,:]

## ◆ parser

palmmeteo_stdplugins.wrf_utils.parser = argparse.ArgumentParser(description=__doc__)

## ◆ phf

palmmeteo_stdplugins.wrf_utils.phf

## ◆ phh

palmmeteo_stdplugins.wrf_utils.phh

## ◆ t

palmmeteo_stdplugins.wrf_utils.t = WRFCoordTransform(f)